
from shop.products.abstract_models import (
    AbstractProduct, AbstractProductCategory, AbstractProductImage)


class ProductCategory(AbstractProductCategory):
    pass


class Product(AbstractProduct):
    pass


class ProductImage(AbstractProductImage):
    pass
