
{% load i18n %}


<div class="modal fade" id="price-offer-modal" tabindex="-1" role="dialog">
    <form method="post" action="{% url 'offers:send' product_pk=product.pk %}">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h4 class="modal-title">
                        {% trans "Запропонувати свою ціну для товару" %}
                    </h4>
                    <h3>{{ product.title }}</h3>
                </div>
                <div class="modal-body">
                    {% include "offers/price_offer_form.html" %}
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default pull-left" data-dismiss="modal">
                        {% trans 'Відмінити' %}
                    </button>
                    <button type="submit" class="btn btn-success" data-role="send-offer-form">
                        {% trans 'Надіслати пропозицію' %}
                    </button>
                </div>
            </div>
        </div>
    </form>
</div>
