
DELIVERY_METHOD_SELF = 1
DELIVERY_METHOD_NOVA_POSHTA = 2
DELIVERY_METHOD_INTIME = 3
DELIVERY_METHOD_GUNSEL = 4
DELIVERY_METHOD_AVTOLUKS = 5
DELIVERY_METHOD_OTHER = 6
DELIVERY_METHOD_MEEST_EXPRESS = 7


PAYMENT_METHOD_CASH = 1
PAYMENT_METHOD_CASHLESS = 2
PAYMENT_METHOD_COD = 3
PAYMENT_METHOD_PRIVAT24 = 4


STATUS_NOT_REVIEWED = 0
STATUS_PROCESSING = 1
STATUS_CANCELED = 2
STATUS_COMPLETED = 3
