
{% load i18n %}


<h1>{% trans 'New price offer #' %} {{ offer.id }}</h1> <br />

<strong>{% trans 'Product title' %}:</strong> <br />
{{ offer.product.title }} <br /><br />

<strong>{% trans 'Name' %}:</strong> <br />
{{ offer.name }} <br /><br />

<strong>{% trans 'Email' %}:</strong> <br />
{{ offer.email }} <br /><br />

<strong>{% trans 'Mobile' %}:</strong> <br />
{{ offer.mobile }} <br /><br />

<strong>{% trans 'Offer' %}:</strong> <br />
{{ offer.text }} <br /><br />

<a href="http://{{ site.domain }}{% url 'admin:offers_productpriceoffer_change' offer.id %}">
    {% trans 'Show in admin' %}
</a> |
<a href="http://{{ site.domain }}{{ offer.product.get_absolute_url }}">
    {% trans 'Show on site' %}
</a>
