# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-03-22 14:45
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('products', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductPriceOffer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.PositiveIntegerField(choices=[(0, 'Not reviewed'), (1, 'Processing'), (2, 'Canceled'), (3, 'Completed')], default=0, verbose_name='Status')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('mobile', models.CharField(max_length=255, verbose_name='Mobile phone')),
                ('email', models.EmailField(max_length=255, verbose_name='Email')),
                ('text', models.TextField(max_length=1000, verbose_name='Offer')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='price_offers', to='products.Product', verbose_name='Product')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='offers', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'ordering': ['-date_created'],
                'verbose_name': 'Product price offer',
                'verbose_name_plural': 'Product price offers',
            },
        ),
    ]
